==> django-froala-editor-1.2.2.tar.gz: django-froala-editor-1.2.2/froala_editor/static/froala_editor/js/langs/it.js <==
/*!
 * froala_editor v1.2.2 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Italian
 */

$.Editable.LANGS['it'] = {
  translation: {
    "Bold": "Grassetto",
    "Italic": "Corsivo",
    "Underline": "Sottolineato",
    "Strikethrough": "Barrato",
    "Font Size": "Dimensione Carattere",
    "Color": "Colore",
    "Background Color": "Colore Sfondo",
    "Text Color": "Colore Testo",
    "Format Block": "Formattazione",
    "Normal": "Normale",
    "Paragraph": "Paragrafo",
    "Code": "Codice",
    "Quote": "Citazione",
    "Heading 1": "Intestazione 1",
    "Heading 2": "Intestazione 2",
    "Heading 3": "Intestazione 3",
    "Heading 4": "Intestazione 4",
    "Heading 5": "Intestazione 5",
    "Heading 6": "Intestazione 6",
    "Block Style": "Stile di blocco",
    "Alignment": "Allineamento",
    "Align Left": "Allinea a Sinistra",
    "Align Center": "Allinea al Cento",
    "Align Right": "Allinea a Destra",
    "Justify": "Giustifica",
    "Numbered List": "Elenchi Numerati",
    "Bulleted List": "Elenchi Puntati",
    "Indent Less": "Riduci Rientro",
    "Indent More": "Aumenta Rientro",
    "Select All": "Seleziona Tutto",
    "Insert Link": "Inserisci Link",
    "Insert Image": "Inserisci Immagine",
    "Insert Video": "Inserisci Video",
    "Undo": "Annulla",
    "Redo": "Ripeti",
    "Show HTML": "Mostra HTML",
    "Float Left": "Sinistra",
    "Float None": "Nessuno",
    "Float Right": "Destra",
    "Replace Image": "Sostituisci Immagine",
    "Remove Image": "Rimuovi Immagine",
    "Title": "Titolo",
    "Insert image": "Inserisci Immagine",
    "Drop image": "Rilascia Immagine",
    "or click": "oppure fai click su",
    "or": "o",
    "Enter URL": "Inserisci URL",
    "Please wait!": "Attendere prego!",
    "Are you sure? Image will be deleted.": "Sei sicuro? Immagine verr\u00e0 cancellata.",
    "UNLINK": "Rimuovi link",
    "Open in new tab": "Apri in nuova scheda",
    "Type something": "Digita qualcosa",
    "Cancel": "Cancella",
    "OK": "Ok",
    "Manage images": "Gestione immagini",
    "Delete": "Cancella",
    "Font Family": "Carattere",
    "Insert Horizontal Line": "Inserisci Divisore Orizzontale",
    "Table": "Tabella",
    "Insert table": "Inserisci Tabella",
    "Cell": "Cella",
    "Row": "Riga",
    "Column": "Colonna",
    "Delete table": "Cancella Tabella",
    "Insert cell before": "Inserisci Cella Prima",
    "Insert cell after": "Inserisci Cella Dopo",
    "Delete cell": "Cancella Cella",
    "Merge cells": "Unisci Cella",
    "Horizontal split": "Divisione Orizzontale",
    "Vertical split": "Divisione Verticale",
    "Insert row above": "Inserisci una Riga Prima",
    "Insert row below": "Inserisci una Riga Dopo",
    "Delete row": "Cancella Riga",
    "Insert column before": "Inserisci una Colonna Prima",
    "Insert column after": "Inserisci una Colonna Dopo",
    "Delete column": "Cancella Colonna"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.3.2.tar.gz: django-froala-editor-1.2.3.2/froala_editor/static/froala_editor/js/langs/it.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Italian
 */

$.Editable.LANGS['it'] = {
  translation: {
    "Bold": "Grassetto",
    "Italic": "Corsivo",
    "Underline": "Sottolineato",
    "Strikethrough": "Barrato",
    "Font Size": "Dimensione Carattere",
    "Color": "Colore",
    "Background": "Sfondo",
    "Text": "Testo",
    "Format Block": "Formattazione",
    "Normal": "Normale",
    "Paragraph": "Paragrafo",
    "Code": "Codice",
    "Quote": "Citazione",
    "Heading 1": "Intestazione 1",
    "Heading 2": "Intestazione 2",
    "Heading 3": "Intestazione 3",
    "Heading 4": "Intestazione 4",
    "Heading 5": "Intestazione 5",
    "Heading 6": "Intestazione 6",
    "Block Style": "Stile di blocco",
    "Alignment": "Allineamento",
    "Align Left": "Allinea a Sinistra",
    "Align Center": "Allinea al Cento",
    "Align Right": "Allinea a Destra",
    "Justify": "Giustifica",
    "Numbered List": "Elenchi Numerati",
    "Bulleted List": "Elenchi Puntati",
    "Indent Less": "Riduci Rientro",
    "Indent More": "Aumenta Rientro",
    "Select All": "Seleziona Tutto",
    "Insert Link": "Inserisci Link",
    "Insert Image": "Inserisci Immagine",
    "Insert Video": "Inserisci Video",
    "Undo": "Annulla",
    "Redo": "Ripeti",
    "Show HTML": "Mostra HTML",
    "Float Left": "Sinistra",
    "Float None": "Nessuno",
    "Float Right": "Destra",
    "Replace Image": "Sostituisci Immagine",
    "Remove Image": "Rimuovi Immagine",
    "Title": "Titolo",
    "Drop image": "Rilascia Immagine",
    "or click": "oppure fai click su",
    "or": "o",
    "Enter URL": "Inserisci URL",
    "Please wait!": "Attendere prego!",
    "Are you sure? Image will be deleted.": "Sei sicuro? Immagine verr\u00e0 cancellata.",
    "UNLINK": "Rimuovi link",
    "Open in new tab": "Apri in nuova scheda",
    "Type something": "Digita qualcosa",
    "Cancel": "Cancella",
    "OK": "Ok",
    "Manage images": "Gestione immagini",
    "Delete": "Cancella",
    "Font Family": "Carattere",
    "Insert Horizontal Line": "Inserisci Divisore Orizzontale",
    "Table": "Tabella",
    "Insert table": "Inserisci Tabella",
    "Cell": "Cella",
    "Row": "Riga",
    "Column": "Colonna",
    "Delete table": "Cancella Tabella",
    "Insert cell before": "Inserisci Cella Prima",
    "Insert cell after": "Inserisci Cella Dopo",
    "Delete cell": "Cancella Cella",
    "Merge cells": "Unisci Cella",
    "Horizontal split": "Divisione Orizzontale",
    "Vertical split": "Divisione Verticale",
    "Insert row above": "Inserisci una Riga Prima",
    "Insert row below": "Inserisci una Riga Dopo",
    "Delete row": "Cancella Riga",
    "Insert column before": "Inserisci una Colonna Prima",
    "Insert column after": "Inserisci una Colonna Dopo",
    "Delete column": "Cancella Colonna"
  },
  direction: "ltr"
};
